<?php
/**
  * Dead Simple Gallery Tester
  * checks your server for compliance with Dead Simple Gallery script
  * 
  * @author Devoth - Łukasz Mazurek - http://www.devoth.com/
  * @version 1.0.1
  * @copyright Devoth Design, 5 May, 2012
  **/
?><!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="utf-8">
  <title>Dead Simple Gallery Tester</title>
  <style>
  body {
    text-align:center;
  }
  .page {
    text-align:left;
    margin:0 auto;
    width:940px;
    min-height:400px;
  }
  h1, h2 {
    font-weight:normal;
    padding-bottom:10px;
    border-bottom:#eee 1px solid;
  }
  .ver {
    font-size:50%;
    color:#999;
  }
  
  table {
    border-collapse:collapse;
    border:none;
  }
  table thead tr {
    border-top:none;
    border-bottom:2px solid black;
  }
  table tr {
    border-top:1px solid black;
  }
  table th {
    padding: 5px 10px;
  }
  table td {
    padding: 5px 10px;
  }
  table th.result,
  table td.result {
    text-align:center;
  }
  .ok {
    color:green;
  }
  .fail {
    color:red;
  }
  
  .summary {
    margin-top:30px;
  }
  .success {
    color:green;
  }
  .error {
    color:red;
  }
  footer {
    color:gray;
    text-align:left;
    margin:0 auto;
    padding-top:10px;
    border-top:#eee 1px solid;
    width:940px;
  }
  </style>
</head>
<body>
  <div class="page">
    <h1>Dead Simple Gallery <strong>Tester</strong> <span class="ver">ver 1.0.1</span></h1>
    <?php
  $output = array();
  $additional_output = array();
  $test_result = true;

  // test for PHP version

  // PHP_VERSION_ID is available as of PHP 5.2.7, if our 
  // version is lower than that, then emulate it
  if (!defined('PHP_VERSION_ID')) {
    $version = explode('.', PHP_VERSION);

    define('PHP_VERSION_ID', ($version[0] * 10000 + $version[1] * 100 + $version[2]));
  }

  // PHP_VERSION_ID is defined as a number, where the higher the number 
  // is, the newer a PHP version is used. It's defined as used in the above 
  // expression:
  //
  // $version_id = $major_version * 10000 + $minor_version * 100 + $release_version;
  //
  // Now with PHP_VERSION_ID we can check for features this PHP version 
  // may have, this doesn't require to use version_compare() everytime 
  // you check if the current PHP version may not support a feature.
  //
  // For example, we may here define the PHP_VERSION_* constants thats 
  // not available in versions prior to 5.2.7

  if (PHP_VERSION_ID < 50207) {
    define('PHP_MAJOR_VERSION',   $version[0]);
    define('PHP_MINOR_VERSION',   $version[1]);
    define('PHP_RELEASE_VERSION', $version[2]);
  }

  if(PHP_MAJOR_VERSION >= 5 && PHP_MINOR_VERSION >= 2) {
    $output[] = array('Your PHP version ' . phpversion() . ', is supported', true);
  }
  else {
    $output[] = array('Your PHP version is not supported', false);
    $test_result = FALSE;
  }




  // test for GD library
  if (extension_loaded('gd') && function_exists('gd_info')) {
    $output[] = array('GD library installed', true);
    $gd_info = gd_info();
    
    if(isset($gd_info['JPG Support'])) {
      $jpg_support = $gd_info['JPG Support'];
      $jpg_support_name = 'JPG Support';
    }
    else if(isset($gd_info['JPEG Support'])) {
      $jpg_support = $gd_info['JPEG Support'];
      $jpg_support_name = 'JPEG Support';
    }
    $gif_read_support = $gd_info['GIF Read Support'];
    $gif_create_support = $gd_info['GIF Create Support'];
    $png_support = $gd_info['PNG Support'];

    $output[] = array($jpg_support_name, $jpg_support);
    $output[] = array('GIF Read Support', $gif_read_support);
    $output[] = array('GIF Create Support', $gif_create_support);
    $output[] = array('PNG Support', $png_support);
    
    if ( ! $jpg_support ) {
      $additional_output[] = 'Your gallery won\'t support JPEG files';
    }
    if ( ! $gif_create_support || ! $gif_read_support ) {
      $additional_output[] = 'Your gallery won\'t support GIF files';
    }
    if ( ! $png_support ) {
      $additional_output[] = 'Your gallery won\'t support PNG files';
    }
    
    if ( ! $jpg_support && ( ! $gif_create_support || ! $gif_read_support) && ! $png_support) {
      $test_result = FALSE;
    }
  }
  else {
    $output[] = array('GD library installed', false);
    
    $output[] = array('JPEG Support', FALSE);
    $output[] = array('GIF Read Support', FALSE);
    $output[] = array('GIF Create Support', FALSE);
    $output[] = array('PNG Support', FALSE);
    $test_result = FALSE;
  }



  // print output
  echo '<table>';
  echo '<thead>';
  echo '<tr><th>Technology</th><th class="result">Test</th></tr>';
  echo '</thead>';
  echo '<tbody>';
  foreach ($output as $value) {
    $result_class = ($value[1]? 'ok' : 'fail');
    $result = ($value[1]? 'Ok' : 'Failed');
    printf('<tr><td>%s</td><td class="result %s">%s</td></tr>', $value[0], $result_class, $result);
  }
  echo '</tbody>';
  echo '</table>';

  if ( $test_result && empty($additional_output) ) {
    echo '<p class="summary success">Dead Simple Gallery should run smoothly on your server.</p>';
  }
  elseif ( $test_result ) {
    echo '<p class="summary">Dead Simple Gallery will run on your server, but you can encounter some problems. See below:</p>';
    echo '<ul>';
    foreach ($additional_output as $value) {
      echo '<li class="error">' . $value . '.</li>';
    }
    echo '</ul>';
  }
  else {
    echo '<p class="summary error">Dead Simple Gallery will not run on your server. Please change the server setup or contact your hosting provider.</p>';
  }
  ?>
</div>
<footer>
  <p class="copyright">&copy; Devoth Design 2012. All rights reserved. Questions? Give us a shout <a href="http://www.devoth.com/contact.html">Devoth Design</a>.</p>
</footer>
</body>
</html>